# -*- coding: utf-8 -*-
from __future__ import division, print_function, absolute_import
import numpy as np
import scipy as sp


def main():
    from pambox.speech import mrsepsm, binauralmrsepsm
    from pambox.distort import WestermannCrm, noise_from_signal
    from pambox import general
    from six.moves import zip

    def load_crm_file(*arg):
        """Read a particular CRM file.

        If the number of argument is 4, the function reads the CRM file corresponding
        to that particular ID, using the file naming scheme 0[0-3]0[0-7]0[0-3]0[0-7],
        where each bracket defines the [speaker], the [call], the [color] and the
        [number], respectively,


        :speaker: int, 0-3
        :call: int, 0-7
        :color: int, 0-3
        :number: int, 0-3
        :return: ndarray, CRM file
        """

        if len(arg) == 4:
            filename = '0%d0%d0%d0%d.wav' % arg
        else:
            filename = arg[0]
        root_name = '../stimuli/crm/crm_files/'
        int_sentence = sp.io.wavfile.read(root_name + filename)
        return np.asarray(int_sentence[1].astype('float') / 2. ** 15)

    w = WestermannCrm()
    s = mrsepsm.MrSepsm(fs=40000)
    bs = binauralmrsepsm.BinauralMrSepsm(fs=40000)

    tdist = 0.5
    mdist = 0.5
    snr = -10.0

    target = load_crm_file(0, 0, 0, 0)
    masker = noise_from_signal(target, fs=40000, keep_env=True)
    target, masker = general.make_same_length(target, masker)
    target, masker = w.apply(target, masker, tdist, mdist)
    target = general.setdbspl(target, 65 + snr, offset=0.0)
    masker = general.setdbspl(masker, 65, offset=0.0)
    res = [s.predict(t, t + m, m) for t, m in zip(target, masker)]

    for r in res:
        print(r.mr_snr_env)

    bres = bs.predict(target, target + masker, masker)


    for ear in bres.ears:
        print(ear.mr_snr_env)
    print(bres.be_mr_snr_env)


if __name__ == "__main__":
    main()
